<?php
/** Araucanian (Mapudungun)
 *
 * @ingroup Language
 * @file
 *
 * @author Clerc
 * @author Lin linao
 * @author Poquil
 * @author Remember the dot
 */

$fallback = 'es';

$messages = array(
# User preference toggles
'tog-editondblclick' => 'Wirin pakina epu klik mew (JavaScript)',

'underline-always' => 'Rumel',
'underline-never'  => 'Turpu',

# Dates
'sunday'        => 'Domingku',
'monday'        => 'Lune',
'tuesday'       => 'Marte',
'wednesday'     => 'Mierkole',
'thursday'      => 'Kuefe',
'friday'        => 'Fierne',
'saturday'      => 'Safado',
'sun'           => 'dom',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mie',
'thu'           => 'kue',
'fri'           => 'fie',
'sat'           => 'saf',
'january'       => 'eneru küyeṉ',
'february'      => 'fewreru küyeṉ',
'march'         => 'marsu küyeṉ',
'april'         => 'afril küyeṉ',
'may_long'      => 'mayu küyeṉ',
'june'          => 'kuniu küyeṉ',
'july'          => 'kuliu küyeṉ',
'august'        => 'akostu küyeṉ',
'september'     => 'setiempüre küyeṉ',
'october'       => 'oktufüre küyeṉ',
'november'      => 'nofiempüre küyeṉ',
'december'      => 'disiempüre küyeṉ',
'january-gen'   => 'eneru küyeṉ',
'february-gen'  => 'fewreru küyeṉ',
'march-gen'     => 'marsu küyeṉ',
'april-gen'     => 'afril küyeṉ',
'may-gen'       => 'mayu küyeṉ',
'june-gen'      => 'kuniu küyeṉ',
'july-gen'      => 'kuliu küyeṉ',
'august-gen'    => 'akostu küyeṉ',
'september-gen' => 'setiempüre küyeṉ',
'october-gen'   => 'oktufüre küyeṉ',
'november-gen'  => 'nofiempüre küyeṉ',
'december-gen'  => 'disiempüre küyeṉ',
'jan'           => 'konlu eneru küyeṉ mew',
'feb'           => 'konlu fewreru küyeṉ mew',
'mar'           => 'konlu marsu küyeṉ mew',
'apr'           => 'konlu afril küyeṉ mew',
'may'           => 'konlu mayu küyeṉ',
'jun'           => 'konlu kuniu küyeṉ mew',
'jul'           => 'konlu kuliu küyeṉ mew',
'aug'           => 'konlu akostu küyeṉ mew',
'sep'           => 'konlu setiempüre küyeṉ mew',
'oct'           => 'konlu oktufüre küyeṉ mew',
'nov'           => 'konlu nofiempüre küyeṉ mew',
'dec'           => 'konlu disiempüre küyeṉ mew',

# Categories related messages
'listingcontinuesabbrev' => 'ramt.',

'qbfind'        => 'Kintun',
'qbedit'        => 'Wirin',
'qbmyoptions'   => 'tañi nütramkawe',
'moredotdotdot' => 'Doy...',
'mypage'        => 'tañi nütramkawe',
'mytalk'        => 'Tañi nütramkawe',
'anontalk'      => 'Tüfachi IP ñi nütramkawe',
'and'           => '&#32;ka',

'returnto'         => 'Amutun $1 püle.',
'tagline'          => '{{SITENAME}} mew',
'help'             => 'Kellu',
'search'           => 'Kintun',
'searchbutton'     => 'Kintun',
'go'               => 'Amun',
'searcharticle'    => 'Amun',
'history'          => 'Pünon',
'history_short'    => 'Pünon',
'edit'             => 'Wirin',
'create'           => 'Llitun',
'editthispage'     => 'Wirin tüfachi página',
'create-this-page' => 'Llitun tüfachi pakina',
'delete'           => 'Ñamümün',
'deletethispage'   => 'Ñamümün tüfachi pakina',
'protect'          => 'Elulan ñi wiriael',
'unprotect'        => 'Elun ñi wiriael',
'newpage'          => 'We Pakina',
'talkpage'         => 'Nütramkafinge tüfachi pakina',
'talkpagelinktext' => 'Nütramkawe',
'personaltools'    => 'Kisungechi küdawpeyüm',
'articlepage'      => 'adkintun artículo',
'talk'             => 'Nütramkawe',
'views'            => 'Pen',
'toolbox'          => 'Küdawpeyüm',
'userpage'         => 'adkintun página de usuario',
'projectpage'      => 'adkintun página meta',
'imagepage'        => 'Adkintun ad pakina',
'mediawikipage'    => 'adkintun página de mensaje',
'templatepage'     => 'adkintun página de plantilla',
'viewhelppage'     => 'adkintun página de ayuda',
'categorypage'     => 'adkintun página de categoría',
'viewtalkpage'     => 'Pen ti nütramkawe',
'otherlanguages'   => 'Kake dungun',
'jumpto'           => 'Amun:',
'jumptosearch'     => 'kintu',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'edithelp'             => 'Kellü wirin',
'edithelppage'         => 'Help:Chum wiringekey pakina',
'faq'                  => 'FAQ',
'faqpage'              => 'Project:FAQ',
'helppage'             => 'Help:Kellu',
'mainpage'             => 'Wüne pakina',
'mainpage-description' => 'Wüne pakina',

'ok'                      => 'Feley may',
'youhavenewmessages'      => 'Elungeymi $1 ($2).',
'newmessageslink'         => 'we dungu',
'youhavenewmessagesmulti' => 'Elungeymi we dungu $1 mew.',
'editsection'             => 'wirin',
'editold'                 => 'wirin',
'editlink'                => 'wirin',
'showtoc'                 => 'pengelün',
'hidetoc'                 => 'ellkan',
'viewdeleted'             => 'Küpaadkintuymi $1 am?',
'restorelink'             => '{{PLURAL:$1|kiñe wirin ñamümgün|$1 wirin ñamümün}}',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Pakina',
'nstab-user'      => 'Kellufe',
'nstab-special'   => 'Kangelu',
'nstab-mediawiki' => 'Dungu',
'nstab-help'      => 'Kelluwe',

# General errors
'filedeleteerror' => 'Pepiñamümüngelay "$1".',
'filenotfound'    => 'Pepipelafuy "$1".',
'badtitle'        => 'Nornongey ta üy',

# Login and logout pages
'loginpagetitle'          => 'Konün',
'yourname'                => 'Tami üy',
'yourpassword'            => 'Tami kondungu',
'login'                   => 'Konün',
'nav-login-createaccount' => 'Konün',
'userlogin'               => 'Konün',
'logout'                  => 'Tripan',
'userlogout'              => 'Tripan',
'notloggedin'             => 'Petu konlaymi.',
'nologin'                 => 'Nielaymi kiñe lludüwe? $1.',
'nologinlink'             => 'Dewmafinge',
'gotaccountlink'          => 'Konün',
'yourrealname'            => 'Tami mupiñ üy *',
'yourlanguage'            => 'Dungun:',
'loginlanguagelabel'      => 'Dungun: $1',

# Edit pages
'subject'            => 'Dungu/üy:',
'minoredit'          => 'Tüfachi ta kiñe pichi wirin',
'watchthis'          => 'Llaytun tüfachi pakina',
'preview'            => 'Pen chum müley',
'showpreview'        => 'Pen chum müley',
'loginreqlink'       => 'Koni',
'newarticle'         => '(We)',
'editing'            => 'Wirimekey $1',
'editingcomment'     => 'Wirin $1 (Dungu)',
'yourtext'           => 'Tami wirin',
'template-protected' => '(Ngünaytun)',

# History pages
'page_first'             => 'wünen',
'history-fieldset-title' => 'Kintun pünon mew',
'deletedrev'             => '[ñamümüngelu]',
'historyempty'           => '(welli)',

# Revision feed
'history-feed-item-nocomment' => '$1 $2 mew', # user at time

# Revision deletion
'rev-delundel'  => 'pengelün/ellkan',
'pagehist'      => 'pünon pakina',
'deletedhist'   => 'Ñamümüngelu pünon',
'revdelete-hid' => 'Ellkan $1',

# Diffs
'lineno'       => 'Wirin $1:',
'editundo'     => 'wüñoeltun',
'diff-movedto' => 'Nengümülu $1 püle',
'diff-img'     => "kiñe '''ad'''",
'diff-big'     => "'''füta'''",
'diff-del'     => "'''Ñamümün'''",

# Search results
'viewprevnext'                   => 'Pen ($1) ($2) ($3).',
'searchhelp-url'                 => 'Help:Kellu',
'searchprofile-articles-tooltip' => 'kintu $1 mew',
'searchprofile-project-tooltip'  => 'Kintun $1 mew',
'search-interwiki-more'          => '(Doy)',
'searchall'                      => 'Fill',
'powersearch'                    => 'Kintun',
'powersearch-field'              => 'Kintun',

# Preferences page
'prefs-edits'       => 'Rakin Wirin:',
'prefsnologin'      => 'Mülelay Konün',
'skin-preview'      => 'Pen chum müley',
'textboxsize'       => 'Wirin',
'searchresultshead' => 'Kintun',

# Groups
'group'       => 'Kisuwen:',
'group-user'  => 'Pu kellufe',
'group-sysop' => 'Pu ngünefe',
'group-all'   => '(kom pu che)',

'group-user-member' => 'Kellufe',

'grouppage-user' => '{{ns:project}}: Pu kellufe',

# Rights
'right-edit'          => 'Wirin pakina',
'right-createpage'    => 'Llitun pakina (nütramkayam pakinanongelu)',
'right-createtalk'    => 'Llitun nütramkayam pakina',
'right-move'          => 'Nengümün pakina',
'right-delete'        => 'Ñamümün pakina',
'right-browsearchive' => 'kintun pakina ñamümüngelu',
'right-undelete'      => 'Wüñoñamümün kiñe pakina',

# User rights log
'rightsnone' => 'chemnorume',

# Associated actions - in the sentence "You do not have permission to X"
'action-move' => 'Nengümün tüfachi pakina',

# Recent changes
'rcshowhideminor'                   => '$1 wirin pichi',
'rcshowhidemine'                    => '$1 tañi wirin',
'hist'                              => 'Püno',
'hide'                              => 'Ellkan',
'show'                              => 'pengelün',
'minoreditletter'                   => 'p',
'newpageletter'                     => 'W',
'number_of_watching_users_pageview' => '[$1 {{PLURAL:$1|Kellufe|Kellufe}} wiñamüy]',

# Recent changes linked
'recentchangeslinked-page' => 'Pakina ñi üy:',

# Upload
'uploadnologin'   => 'Petu konlaymi',
'watchthisupload' => 'Llaytun tüfachi pakina',

'nolicense' => 'Chemnorume dullinnongey',

# Special:ListFiles
'listfiles_name' => 'Üy',
'listfiles_user' => 'Kellufe',

# File description page
'filehist-deleteall' => 'kom ñamümün',
'filehist-deleteone' => 'ñamümün tüfa',
'filehist-user'      => 'Kellufe',

# File deletion
'filedelete'                 => '$1 ñamümün',
'filedelete-intro'           => "Ñamümmekeymi '''[[Media:$1|$1]]'''.",
'filedelete-submit'          => 'Ñamümün',
'filedelete-success'         => "'''$1''' ñamümngey.",
'filedelete-edit-reasonlist' => 'Wirin dungu ñamümgün mew',

# Unused templates
'unusedtemplateswlh' => "Kake ''enlase''",

# Statistics
'statistics-pages' => 'Pakina',

'brokenredirects-edit'   => '(wirin)',
'brokenredirects-delete' => '(ñamümün)',

'withoutinterwiki-submit' => 'Pengelün',

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1|byte|bytes}}',
'nviews'            => '$1 {{PLURAL:$1|pen|pen}}',
'shortpages'        => 'Pichi pakina',
'newpages'          => 'We pakina',
'newpages-username' => 'Kellufe ñi üy',
'move'              => 'Wiñamün',
'movethispage'      => 'Nengümün tüfachi pakina',

# Book sources
'booksources-go' => 'Amun',

# Special:Log
'specialloguserlabel'  => 'Kellufe:',
'speciallogtitlelabel' => 'Üy:',

# Special:AllPages
'allpages'       => 'Kakelu pakina',
'allarticles'    => 'Fill pakina',
'allpagesnext'   => 'Inan',
'allpagessubmit' => 'Pengelün',

# Special:LinkSearch
'linksearch-ok' => 'Kintun',

# Special:ListUsers
'listusers-submit' => 'Pengelün',

# E-mail user
'emailsubject' => 'Dungu',
'emailmessage' => 'Dungu',
'emailsend'    => 'Werkün',

# Watchlist
'watchlistfor'    => "('''$1''')",
'watchnologin'    => 'Petu konlaymi',
'watch'           => 'Llaytun',
'watchthispage'   => 'Llaytun tüfachi pakina',
'unwatch'         => 'Llaytuwelan',
'unwatchthispage' => 'Llaytuwelan',
'notanarticle'    => 'Ngelay kiñe pakina',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Llaytumekey...',
'unwatching' => 'Llaytumekewelay...',

'enotif_newpagetext'           => 'Tüfachi ta we pakina',
'enotif_impersonal_salutation' => '{{SITENAME}} kellufe',
'created'                      => 'Llituy',

# Delete
'deletepage'     => 'Ñamümün tüfachi pakina',
'exblank'        => 'pakina wellingey',
'delete-confirm' => 'Ñamümüngelu "$1"',
'delete-legend'  => 'Ñamümün',
'deletedarticle' => '«[[$1]]» Ñamümün',

# Protect
'prot_1movedto2'          => '[[$1]] wiñamngey [[$2]] püle',
'protectexpiry'           => 'Afi:',
'protect-level-sysop'     => 'Pu ngünefe müṯen',
'protect-summary-cascade' => 'Trayengko',
'protect-expiry-options'  => '1 ora:1 hour,1 aṉtü:1 day,1 semana:1 week,2 semanas:2 weeks,1 küyeṉ:1 month,3 küyeṉ:3 months,6 küyeṉ:6 months,1 tripantu:1 year,Rumel:infinite', # display1:time1,display2:time2,...

# Restrictions (nouns)
'restriction-edit'   => 'Pepiwelukay',
'restriction-move'   => 'Pepiwiñami',
'restriction-create' => 'Llitun',

# Undelete
'viewdeletedpage'           => 'Pen pakina ñamümüngelu',
'undelete-search-box'       => 'Kintun ñamümüngelu pakina',
'undelete-search-submit'    => 'Kintun',
'undelete-show-file-submit' => 'May',

# Namespace form on various pages
'blanknamespace' => '(Wüne pakina)',

# Contributions
'contribsub2' => '$1 ($2)',
'month'       => 'Küyeṉ:',
'year'        => 'Tripantu:',

'sp-contributions-submit' => 'Kintun',

# What links here
'whatlinkshere-page' => 'Pakina:',
'whatlinkshere-prev' => '{{PLURAL:$1|Pen chum müley|Pen chum müluey $1}}',

# Block/unblock
'ipbexpiry'          => 'Afi',
'ipboptions'         => '2 ora:2 hours,1 aṉtü:1 day,3 aṉtü:3 days,1 semana:1 week,2 semana:2 weeks,1 küyeṉ:1 month,3 küyeṉ:3 months,6 küyeṉ:6 months,1 tripantu:1 year,rumel:infinite', # display1:time1,display2:time2,...
'ipbotheroption'     => 'Kakelu',
'ipblocklist-submit' => 'Kintun',
'expiringblock'      => 'afi $1',
'proxyblocksuccess'  => 'Dewmangey.',

# Move page
'move-page'               => 'Nengümün $1',
'move-page-legend'        => 'Nengümün pakina',
'movearticle'             => 'Nengümün pakina',
'movenologin'             => 'Konlaymi',
'newtitle'                => 'We üy püle',
'move-watch'              => 'Llaytun tüfachi pakina',
'movepagebtn'             => 'Nengümün pakina',
'movedto'                 => 'Nengümün',
'1movedto2'               => '[[$1]] wiñamngey [[$2]] püle',
'delete_and_move'         => 'Ñamümün ka nengümün',
'delete_and_move_confirm' => 'May, ñamümün pakina',

# Export
'export' => 'Wiñamün pakina',

# Namespace 8 related
'allmessagesname' => 'Üy',

# Tooltip help for the actions
'tooltip-pt-userpage'    => 'Tañi pakina',
'tooltip-pt-mytalk'      => 'Tañi nütramkawe',
'tooltip-pt-logout'      => 'Tripan',
'tooltip-ca-delete'      => 'Ñamümün tüfachi pakina',
'tooltip-ca-move'        => 'Nengümün tüfachi pakina',
'tooltip-search'         => 'Kintun tüfachi wiki mew',
'tooltip-p-logo'         => 'Wüne pakina',
'tooltip-ca-nstab-user'  => 'Pen kellufe pakina',
'tooltip-ca-nstab-image' => 'Pen pakina ad mew',
'tooltip-ca-nstab-help'  => 'Pen kellupakina',

# Attribution
'siteuser'  => 'Kellufe $1 {{SITENAME}}',
'others'    => 'fill',
'siteusers' => '{{PLURAL:$2|Kellufe|Kellufe}} $1 {{SITENAME}}',

# Info page
'numedits'     => 'Rakin wirin (pakina): $1',
'numtalkedits' => 'Rakin wirin (pakina nütramkawe): $1',

# Patrol log
'patrol-log-diff' => 'ng$1',

# Browsing diffs
'previousdiff' => '← Füta wirin',
'nextdiff'     => 'We wirin →',

# Special:NewFiles
'ilsubmit' => 'Kintu',

# Video information, used by Language::formatTimePeriod() to format lengths in the above messages
'hours-abbrev' => 'o',

# EXIF tags
'exif-artist'              => 'Che llitun mew',
'exif-exposuretime-format' => '$1 sek ($2)',

'exif-exposureprogram-1' => 'Chillka kellu',

'exif-meteringmode-0'   => 'Kimnoelchi',
'exif-meteringmode-255' => 'Kakelu',

'exif-lightsource-0' => 'Kimnoelchi',

'exif-gaincontrol-0' => 'Chemnorume',

'exif-contrast-2' => 'Yafü',

'exif-sharpness-2' => 'Yafü',

'exif-subjectdistancerange-0' => 'Kimnoelchi',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'kom',
'imagelistall'     => 'kom',
'watchlistall2'    => 'Fill',
'namespacesall'    => 'kom',
'monthsall'        => '(kom)',

# Trackbacks
'trackbackremove' => ' ([$1 Ñamümün])',

# action=purge
'confirm_purge_button' => 'Feley may',

# Multipage image navigation
'imgmultigo' => 'Amun!',

# Table pager
'table_pager_limit_submit' => 'Amun',

# Size units
'size-bytes'     => '$1 b',
'size-kilobytes' => '$1 Kb',
'size-megabytes' => '$1 Mb',
'size-gigabytes' => '$1 Gb',

# Special:Version
'version-other' => 'Kakelu',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Kintun',

# Special:SpecialPages
'specialpages-group-login'     => 'Konün',
'specialpages-group-pagetools' => 'Küsawkawe pakina mew',

# Special:BlankPage
'blankpage' => 'welli pakina',

);
